.. _underthehood:

===========================================
Under-the-hood documentation for developers
===========================================

These documents are intended as a low-level look into NumPy; focused
towards developers.

.. toctree::
   :maxdepth: 1

   internals
   internals.code-explanations
   alignment
   ../user/byteswapping
   ../user/basics.dispatch
   ../user/basics.subclassing

